aboutsummaryrefslogtreecommitdiffstats
path: root/hicn-plugin/src/route.h
diff options
context:
space:
mode:
Diffstat (limited to 'hicn-plugin/src/route.h')
-rw-r--r--hicn-plugin/src/route.h92
1 files changed, 47 insertions, 45 deletions
diff --git a/hicn-plugin/src/route.h b/hicn-plugin/src/route.h
index a1ba86b3d..4fcb219c8 100644
--- a/hicn-plugin/src/route.h
+++ b/hicn-plugin/src/route.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2017-2020 Cisco and/or its affiliates.
+ * Copyright (c) 2021 Cisco and/or its affiliates.
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at:
@@ -24,27 +24,30 @@
/**
* @file route.h
*
- * hICN uses a specific vrf to install the routes for a prefix has been enabled to
- * be hicn. It considers the vrf 0 (the default vrf) as the dominating vrf on
- * which every route is stored. Enabling a prefix to be hICN will copy all the routes
- * in the vrf 0 for the given prefi, in the vrf HICN. Every modification made on the
- * vrf 0 on an hICN enabled prefix is reflected in the vrf hICN (through the use of
- * the fib entry tracking functionality). Moreover, we use the lookup in the vrf hICN
- * as a way for punting packet that must be processed as hICN. The implementation will
- * install a special dpo as a single next hop for the vpp load balancer for each entry
- * in the vrf hICN that we enabled. Such dpo will have two purposes: 1) to punt packets
- * to the hICN forwarding pipeline, 2) to point to the righe strategy (the dpoi_index will
- * be an index to the strategy context while the dpoi_type will be an index to the strategy vft).
+ * hICN uses a specific vrf to install the routes for a prefix has been enabled
+ * to be hicn. It considers the vrf 0 (the default vrf) as the dominating vrf
+ * on which every route is stored. Enabling a prefix to be hICN will copy all
+ * the routes in the vrf 0 for the given prefi, in the vrf HICN. Every
+ * modification made on the vrf 0 on an hICN enabled prefix is reflected in the
+ * vrf hICN (through the use of the fib entry tracking functionality).
+ * Moreover, we use the lookup in the vrf hICN as a way for punting packet that
+ * must be processed as hICN. The implementation will install a special dpo as
+ * a single next hop for the vpp load balancer for each entry in the vrf hICN
+ * that we enabled. Such dpo will have two purposes: 1) to punt packets to the
+ * hICN forwarding pipeline, 2) to point to the righe strategy (the dpoi_index
+ * will be an index to the strategy context while the dpoi_type will be an
+ * index to the strategy vft).
*
- * Additionally, hICN assign each interface to the vrf hICN; this is required for
- * the interest lookup. Vpp performs a lookup in the vrf assigned to the interface,
- * therefore if an interface is not assigned to the hICN vrf, the lookup will be done
- * on the vrf 0 and the packet won't be processed through the hicn forwarding pipeline.
+ * Additionally, hICN assign each interface to the vrf hICN; this is required
+ * for the interest lookup. Vpp performs a lookup in the vrf assigned to the
+ * interface, therefore if an interface is not assigned to the hICN vrf, the
+ * lookup will be done on the vrf 0 and the packet won't be processed through
+ * the hicn forwarding pipeline.
*/
/*
- * Adding each interface to the vrf hICN has the side effect that to ping you need to
- * specify the vrf hICN in the command.
+ * Adding each interface to the vrf hICN has the side effect that to ping you
+ * need to specify the vrf hICN in the command.
*/
extern fib_source_t hicn_fib_src;
@@ -58,10 +61,8 @@ extern dpo_type_t udp_encap_dpo_types[FIB_PROTOCOL_MAX];
* @param hicn_dpo return value with the hicn_dpo
* @param fib_index return value with the fib index corresponding to the prefix
*/
-int
-hicn_route_get_dpo (const fib_prefix_t * prefix,
- const dpo_id_t ** hicn_dpo, u32 * fib_index);
-
+int hicn_route_get_dpo (const fib_prefix_t *prefix, const dpo_id_t **hicn_dpo,
+ u32 *fib_index);
/**
* @Brief Set the strategy for a given prefix
@@ -69,44 +70,48 @@ hicn_route_get_dpo (const fib_prefix_t * prefix,
* @param prefix Prefix for which we set the strategy
* @param stretegy_id Index of the strategy to set
*/
-int
-hicn_route_set_strategy (fib_prefix_t * prefix, u32 strategy_id);
+int hicn_route_set_strategy (fib_prefix_t *prefix, u32 strategy_id);
/**
* @Brief Helper to add a nex hop in the vrf 0. If there are no entries in the
* vrf 0 that matches with the prefix (epm), a new one is created.
*
* @param fib_proto FIB_PROTOCOL_IP6 or FIB_PROTOCOL_IP4 (mpls not supported)
- * @param pfx Prefix for which to add a next hop
+ * @param rpfx Prefix for which to add a next hop
* @param nh Next hop to add
* @param sw_if Software interface index to add in the next hop
*/
-int
-ip_nh_add_helper (fib_protocol_t fib_proto, const fib_prefix_t * pfx, ip46_address_t * nh, u32 sw_if);
+int ip_nh_adj_add_del_helper (fib_protocol_t fib_proto,
+ const fib_prefix_t *rpfx, ip46_address_t *nh,
+ u32 sw_if, u8 is_add);
/**
- * @Brief Helper to remove a nex hop in the vrf 0. If there are no entries in the
- * vrf 0 nothing happens.
+ * @Brief Helper to add an udp-tunnel nex hop in the vrf 0. If there are no
+ * entries in the vrf 0 that matches with the prefix (epm), a new one is
+ * created.
*
* @param fib_proto FIB_PROTOCOL_IP6 or FIB_PROTOCOL_IP4 (mpls not supported)
- * @param pfx Prefix for which to remove a next hop
- * @param nh Next hop to remove
- * @param sw_if Software interface index in the next hop definition
+ * @param rpfx Prefix for which to add a next hop
+ * @param uei The UDP ENCAP ID
+ * @param proto The payload proto for this encap
*/
-int
-ip_nh_del_helper (fib_protocol_t fib_proto, const fib_prefix_t * rpfx, ip46_address_t * nh, u32 sw_if);
+int ip_nh_udp_tunnel_add_del_helper (fib_protocol_t fib_proto,
+ const fib_prefix_t *rpfx, u32 uei,
+ dpo_proto_t proto, u8 is_add);
/**
* @Brief Enable an hICN for an ip prefix
*
* @param prefix Prefix for which we enable hICN
* @return HICN_ERROR_NONE if hICN was enabled on the prefix
- * HICN_ERROR_ROUTE_NO_LD if the first dpo for the fib entry corresponding to the prefix is not a load_balancer
- * HICN_ERROR_ROUTE_DPO_NO_HICN if the loadbalancer in the vrf HICN already contains a dpo which is not an hICN one
+ * HICN_ERROR_ROUTE_NO_LD if the first dpo for the fib entry corresponding to
+ * the prefix is not a load_balancer HICN_ERROR_ROUTE_DPO_NO_HICN if the
+ * loadbalancer in the vrf HICN already contains a dpo which is not an hICN one
* HICN_ERROR_ROUTE_MLT_LD if there are more than a dpo in the vpp loadbalancer
*/
-int
-hicn_route_enable (fib_prefix_t *prefix);
+int hicn_route_enable (const fib_prefix_t *prefix,
+ fib_node_index_t *hicn_fib_node_index,
+ hicn_face_id_t **vec_faces);
/**
* @Brief Disable an hICN for an ip prefix. If hICN wasn't enable on the prefix
@@ -114,13 +119,10 @@ hicn_route_enable (fib_prefix_t *prefix);
*
* @param prefix Prefix for which we disable hICN
*/
-int
-hicn_route_disable (fib_prefix_t *prefix);
-
+int hicn_route_disable (fib_prefix_t *prefix);
/* Init route internal strustures */
-void
-hicn_route_init();
+void hicn_route_init ();
#endif /* //__HICN_ROUTE__ */
/*
@@ -69,44 +70,48 @@ hicn_route_get_dpo (const fib_prefix_t * prefix,
/**
- * @Brief Helper to add a nex hop in the vrf 0. If there are no entries in the
- * vrf 0 that matches with the prefix (epm), a new one is created.
+ * @Brief Helper to add an adj nex hop in the vrf 0. If there are no entries in
+ * the vrf 0 that matches with the prefix (epm), a new one is created.
*
* @param fib_proto FIB_PROTOCOL_IP6 or FIB_PROTOCOL_IP4 (mpls not supported)